@@ -16,13 +16,16 @@ class SpacyCleaner(BasePreprocessor):
         return token.lemma_.lower()
 
     def process_text(self, text):
-        def is_valid(token):
-            return token.is_alpha and not token.is_stop and len(
-                    token) > MIN_TOKEN_LENGTH
 
         return [self._process_token(token) for token in nlp(text) if
-                is_valid(token)]
+                _is_valid(token)]
 
     def process_documents(self, docs: List):
         for doc in tqdm(nlp.pipe(docs, batch_size=30)):
-            yield [self._process_token(token) for token in doc]
+            yield [self._process_token(token) for token in doc if
+                   _is_valid(token)]
+
+
+def _is_valid(token):
+    return token.is_alpha and not token.is_stop and len(
+            token) > MIN_TOKEN_LENGTH
